@@ -29,8 +29,12 @@ namespace KFileMetaData
 
 class PopplerExtractor : public ExtractorPlugin
 {
+    Q_OBJECT
+    Q_PLUGIN_METADATA(IID "org.kde.kf5.kfilemetadata.ExtractorPlugin")
+    Q_INTERFACES(KFileMetaData::ExtractorPlugin)
+
 public:
-    PopplerExtractor(QObject* parent, const QVariantList&);
+    PopplerExtractor(QObject* parent = 0);
 
     virtual QStringList mimetypes() const;
     virtual void extract(ExtractionResult* result);
