@@ -57,44 +57,11 @@ QString UserMetaData::filePath() const
     return d->filePath;
 }
 
-void UserMetaData::addTag(const QString& tag)
-{
-    QSet<QString> tagSet = tags().toSet();
-    tagSet << tag;
-
-    setTags(tagSet.toList());
-}
-
-void UserMetaData::addTags(const QStringList& tagList)
-{
-    QSet<QString> tagSet = tags().toSet();
-    tagSet.unite(tagList.toSet());
-
-    setTags(tagSet.toList());
-}
-
 void UserMetaData::setTags(const QStringList& tags)
 {
     k_setxattr(d->filePath, QStringLiteral("user.xdg.tags"), tags.join(", "));
 }
 
-void UserMetaData::removeTag(const QString& tag)
-{
-    QSet<QString> tagSet = tags().toSet();
-    tagSet.remove(tag);
-
-    setTags(tagSet.toList());
-}
-
-void UserMetaData::removeTags(const QStringList& tagList)
-{
-    QSet<QString> tagSet = tags().toSet();
-    tagSet.subtract(tagList.toSet());
-
-    setTags(tagSet.toList());
-
-}
-
 QStringList UserMetaData::tags() const
 {
     QString value;
@@ -131,12 +98,12 @@ void UserMetaData::setUserComment(const QString& userComment)
 
 void UserMetaData::setAttribute(const QString& key, const QString& value)
 {
-    k_setxattr(d->filePath, QStringLiteral("user") + key, value);
+    k_setxattr(d->filePath, QStringLiteral("user.") + key, value);
 }
 
 bool UserMetaData::hasAttribute(const QString& key)
 {
-    k_getxattr(d->filePath, QStringLiteral("user") + key, 0);
+    k_getxattr(d->filePath, QStringLiteral("user.") + key, 0);
 
     return (errno != ENODATA);
 }
@@ -144,7 +111,7 @@ bool UserMetaData::hasAttribute(const QString& key)
 QString UserMetaData::attribute(const QString& key)
 {
     QString value;
-    k_getxattr(d->filePath, QStringLiteral("user") + key, &value);
+    k_getxattr(d->filePath, QStringLiteral("user.") + key, &value);
 
     return value;
 }
